Crate fsqlite_c_api

Crate fsqlite_c_api 

Structs

CompatMetricsSnapshot
Sqlite3
Opaque database connection handle exposed via C FFI.
Sqlite3Stmt

Constants

SQLITE_ABORT
SQLITE_AUTH
SQLITE_BLOB
SQLITE_BUSY
SQLITE_CANTOPEN
SQLITE_CONSTRAINT
SQLITE_CORRUPT
SQLITE_DONE
SQLITE_ERROR
SQLITE_FLOAT
SQLITE_FULL
SQLITE_INTEGER
SQLITE_INTERNAL
SQLITE_IOERR
SQLITE_MISMATCH
SQLITE_MISUSE
SQLITE_NOMEM
SQLITE_NOTADB
SQLITE_NULL
SQLITE_OK
SQLITE_RANGE
SQLITE_READONLY
SQLITE_ROW
SQLITE_SCHEMA
SQLITE_TEXT
SQLITE_TOOBIG

Functions

compat_metrics_snapshot
reset_compat_metrics
sqlite3_changes
Return the number of rows modified by the most recent INSERT/UPDATE/DELETE.
sqlite3_close
Close a database connection.
sqlite3_column_blob
Get a blob pointer from column i_col.
sqlite3_column_bytes
Get the byte size of a blob or text value in column i_col.
sqlite3_column_count
Number of columns in the result set.
sqlite3_column_double
Get a double value from column i_col.
sqlite3_column_int
Get a 32-bit integer value from column i_col.
sqlite3_column_int64
Get an integer value from column i_col.
sqlite3_column_text
Get a text pointer from column i_col.
sqlite3_column_type
Type of value in column i_col of the current row.
sqlite3_errcode
Get the most recent error code.
sqlite3_errmsg
Get the most recent error message.
sqlite3_exec
Execute one or more SQL statements.
sqlite3_finalize
Destroy a prepared statement.
sqlite3_free
Free memory allocated by this library (for errmsg from sqlite3_exec).
sqlite3_open
Open a new database connection.
sqlite3_prepare_v2
Compile an SQL statement.
sqlite3_reset
Reset a prepared statement so it can be stepped again.
sqlite3_step
Step through a prepared statement.