sqlite3_column_bytes

Function sqlite3_column_bytes 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn sqlite3_column_bytes( stmt: *mut Sqlite3Stmt, i_col: c_int, ) -> c_int
Get the byte size of a blob or text value in column i_col.

Safety

stmt must be a valid handle with an active row.