Structs
- Compat
Metrics Snapshot - Sqlite3
- Opaque database connection handle exposed via C FFI.
- Sqlite3
Stmt
Constants
- SQLITE_
ABORT - SQLITE_
AUTH - SQLITE_
BLOB - SQLITE_
BUSY - SQLITE_
CANTOPEN - SQLITE_
CONSTRAINT - SQLITE_
CORRUPT - SQLITE_
DONE - SQLITE_
ERROR - SQLITE_
FLOAT - SQLITE_
FULL - SQLITE_
INTEGER - SQLITE_
INTERNAL - SQLITE_
IOERR - SQLITE_
MISMATCH - SQLITE_
MISUSE - SQLITE_
NOMEM - SQLITE_
NOTADB - SQLITE_
NULL - SQLITE_
OK - SQLITE_
RANGE - SQLITE_
READONLY - SQLITE_
ROW - SQLITE_
SCHEMA - SQLITE_
TEXT - SQLITE_
TOOBIG
Functions
- compat_
metrics_ snapshot - reset_
compat_ metrics - sqlite3_
changes ⚠ - Return the number of rows modified by the most recent INSERT/UPDATE/DELETE.
- sqlite3_
close ⚠ - Close a database connection.
- sqlite3_
column_ ⚠blob - Get a blob pointer from column
i_col. - sqlite3_
column_ ⚠bytes - Get the byte size of a blob or text value in column
i_col. - sqlite3_
column_ ⚠count - Number of columns in the result set.
- sqlite3_
column_ ⚠double - Get a double value from column
i_col. - sqlite3_
column_ ⚠int - Get a 32-bit integer value from column
i_col. - sqlite3_
column_ ⚠int64 - Get an integer value from column
i_col. - sqlite3_
column_ ⚠text - Get a text pointer from column
i_col. - sqlite3_
column_ ⚠type - Type of value in column
i_colof the current row. - sqlite3_
errcode ⚠ - Get the most recent error code.
- sqlite3_
errmsg ⚠ - Get the most recent error message.
- sqlite3_
exec ⚠ - Execute one or more SQL statements.
- sqlite3_
finalize ⚠ - Destroy a prepared statement.
- sqlite3_
free ⚠ - Free memory allocated by this library (for errmsg from
sqlite3_exec). - sqlite3_
open ⚠ - Open a new database connection.
- sqlite3_
prepare_ ⚠v2 - Compile an SQL statement.
- sqlite3_
reset ⚠ - Reset a prepared statement so it can be stepped again.
- sqlite3_
step ⚠ - Step through a prepared statement.