#[unsafe(no_mangle)]pub unsafe extern "C" fn sqlite3_column_text(
stmt: *mut Sqlite3Stmt,
i_col: c_int,
) -> *const c_charExpand description
Get a text pointer from column i_col.
The returned pointer is valid until the next sqlite3_step,
sqlite3_reset, or sqlite3_finalize on this statement.
Safety
stmt must be a valid handle with an active row.